// OpenBSD-specific defaults overrides
pref("media.autoplay.default", 1);
pref("app.shield.optoutstudies.enabled", false);
pref("app.normandy.enabled",false);
pref("browser.safebrowsing.enabled", false);
pref("browser.safebrowsing.malware.enabled", false);
pref("spellchecker.dictionary_path", "/usr/local/share/mozilla-dicts/");
pref("extensions.pocket.enabled", false);
pref("browser.newtabpage.enabled", false);
pref("browser.startup.homepage", "about:blank");
pref("network.trr.mode", 5);
